summaryrefslogtreecommitdiffstats
path: root/chalk/core/kis_layer.cc
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /chalk/core/kis_layer.cc
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'chalk/core/kis_layer.cc')
-rw-r--r--chalk/core/kis_layer.cc18
1 files changed, 9 insertions, 9 deletions
diff --git a/chalk/core/kis_layer.cc b/chalk/core/kis_layer.cc
index 752159c0..2b7307e5 100644
--- a/chalk/core/kis_layer.cc
+++ b/chalk/core/kis_layer.cc
@@ -341,7 +341,7 @@ void KisLayer::setDirty(bool propagate)
if (rc.isValid()) m_dirtyRect = rc;
// If we're dirty, our tqparent is dirty, if we've got a tqparent
if (propagate && m_parent && rc.isValid()) m_parent->setDirty(m_dirtyRect);
if (m_image && rc.isValid()) {
@@ -351,7 +351,7 @@ void KisLayer::setDirty(bool propagate)
void KisLayer::setDirty(const TQRect & rc, bool propagate)
{
// If we're dirty, our tqparent is dirty, if we've got a tqparent
if (rc.isValid())
m_dirtyRect |= rc;
@@ -364,23 +364,23 @@ void KisLayer::setDirty(const TQRect & rc, bool propagate)
}
}
-KisGroupLayerSP KisLayer::tqparent() const
+KisGroupLayerSP KisLayer::parent() const
{
return m_parent;
}
KisLayerSP KisLayer::prevSibling() const
{
- if (!tqparent())
+ if (!parent())
return 0;
- return tqparent()->at(index() - 1);
+ return parent()->at(index() - 1);
}
KisLayerSP KisLayer::nextSibling() const
{
- if (!tqparent())
+ if (!parent())
return 0;
- return tqparent()->at(index() + 1);
+ return parent()->at(index() + 1);
}
int KisLayer::index() const
@@ -390,9 +390,9 @@ int KisLayer::index() const
void KisLayer::setIndex(int i)
{
- if (!tqparent())
+ if (!parent())
return;
- tqparent()->setIndex(this, i);
+ parent()->setIndex(this, i);
}
KisLayerSP KisLayer::findLayer(const TQString& n) const
@@ -341,7 +341,7 @@ void KisLayer::setDirty(bool propagate)
if (rc.isValid()) m_dirtyRect = rc;
- // If we're dirty, our tqparent is dirty, if we've got a tqparent
+ // If we're dirty, our parent is dirty, if we've got a parent
if (propagate && m_parent && rc.isValid()) m_parent->setDirty(m_dirtyRect);
if (m_image && rc.isValid()) {
@@ -351,7 +351,7 @@ void KisLayer::setDirty(bool propagate)
void KisLayer::setDirty(const TQRect & rc, bool propagate)
{
- // If we're dirty, our tqparent is dirty, if we've got a tqparent
+ // If we're dirty, our parent is dirty, if we've got a parent
if (rc.isValid())
m_dirtyRect |= rc;